@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: keys
 version: 3.11
-id: keys-3.11-e8b0d316d522e372d8b8151d1187a042
-key: keys_Ldu6L5NVqQzD3K4u1poYwC
+id: keys-3.11-138176c47b9b6dd0d393596bbcd2f16d
+key: keys_KQY4bQGDmrS1PTYlRp6s52
 license: BSD3
 copyright: Copyright (C) 2011-2016 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -21,19 +21,19 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/keys-3.11
 library-dirs: /usr/lib/ghc-7.10.3/site-local/keys-3.11
 data-dir: /usr/share/arm-linux-ghc-7.10.3/keys-3.11
-hs-libraries: HSkeys-3.11-Ldu6L5NVqQzD3K4u1poYwC
+hs-libraries: HSkeys-3.11-KQY4bQGDmrS1PTYlRp6s52
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    comonad-5-9a3bede31f7f9dbe4efd0f02bc9ca766
+    comonad-5-a91321d086a2de4a04a44d60c347669e
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    free-4.12.4-00d655da7510c123b23f3d4ff9d2e676
+    free-4.12.4-d9a4c0f5afbed93cf1b5cb75cd23ad91
     hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
-    semigroupoids-5.0.1-e4734876ceb621b0eefb491ac209dad3
-    semigroups-0.18.1-34c490e60d2f8a8cae75b79e944c6c08
+    semigroupoids-5.0.1-d6a1ac9616a3b8232f6b4a54c12a0db0
+    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
-    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
+    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
 haddock-interfaces: /usr/share/doc/haskell-keys/html/keys.haddock
 haddock-html: /usr/share/doc/haskell-keys/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
